package com.traffic.dashboard;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.messaging.simp.SimpMessagingTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import com.traffic.dao.POITrafficDataRepository;
import com.traffic.dao.TotalTrafficDataRepository;
import com.traffic.dao.WindowTrafficDataRepository;
import com.traffic.dao.entity.POITrafficData;
import com.traffic.dao.entity.TotalTrafficData;
import com.traffic.dao.entity.WindowTrafficData;
import com.traffic.vo.Response;


@Service
public class TrafficDataService {
	
	@Autowired
	private SimpMessagingTemplate template;
	
	@Autowired
	private TotalTrafficDataRepository totalRepository;
	
	@Autowired
	private WindowTrafficDataRepository windowRepository;
	
	@Autowired
	private POITrafficDataRepository poiRepository;
	
	private static DateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
	
	//Method sends traffic data message in every 5 seconds.
	@Scheduled(fixedRate = 5000)
	public void trigger() {
		List<TotalTrafficData> totalTrafficList = new ArrayList<TotalTrafficData>();
		List<WindowTrafficData> windowTrafficList = new ArrayList<WindowTrafficData>();
		List<POITrafficData> poiTrafficList = new ArrayList<POITrafficData>();
		//Call dao methods
		totalRepository.findTrafficDataByDate(sdf.format(new Date())).forEach(e -> totalTrafficList.add(e));	
		windowRepository.findTrafficDataByDate(sdf.format(new Date())).forEach(e -> windowTrafficList.add(e));	
		poiRepository.findAll().forEach(e -> poiTrafficList.add(e));
		//prepare response
		Response response = new Response();
		response.setTotalTraffic(totalTrafficList);
		response.setWindowTraffic(windowTrafficList);
		response.setPoiTraffic(poiTrafficList);
		System.out.println("Sending to UI "+response);
		//send to ui
		this.template.convertAndSend("/topic/trafficData", response);
	}
	
}
